#!/bin/bash
archive=MicroBrowser_x11.zip
URL=http://ininet.ch/delivery/Ubuntu/x86_64/$archive

echo "Installation of SpiderControl MicroBrowser X11 for Linux x86_x64"
echo "User: $USER"
echo "Home: $HOME"
echo "Download: $URL"
echo "Installation will be done under ${HOME}/MicroBrowser/"

# Integrity check
[ ! -d $HOME ] && echo "Error: $HOME directory does not exist!" && exit 1
[ $(uname -s) != "Linux" ] && echo "Error: Is not Linux" && uname -a && exit 2
[ $(uname -m) != "x86_64" ] && echo "Error: Is not x86_64" && uname -a && exit 3
[ $USER == "root" ] && echo "Error: Do not install the software as root or su" && exit 4

echo -n "> Install or update SpiderControl MicroBrowser X11 (y/n)? "
read answer
if [ "$answer" != "${answer#[Yy]}" ] ; then
    echo "Yes"
else
    echo "No" && exit 0
fi

# Create tmp directory
tmp_dir=$(mktemp -d -t mbrow-XXXXXXXXXX)
echo "tmp dir: $tmp_dir"
err=$?
if [ $err -ne 0 ] ; then
  echo "Exit on error: $err"
  exit $err
fi
echo $tmp_dir
cd $tmp_dir
# Check if current directory is tmp_dir
[ $PWD != $tmp_dir ] && echo "Failed to create temp directory $tmp_dir" && exit 13

# Download archive file
wget -O $archive $URL
[ $? -ne 0 ] && rm -f $archive && rm -rf $tmp_dir && echo "Exit on error" && exit 14

# Check if file exist and is not empty
[ ! -s $archive ] && echo "Error: File not found or empty: $archive" && exit 15
echo "Extract $archive"
unzip -q $archive
[ ! -d MicroBrowser ] && echo "MicroBrowser directory not found!" && exit 16

chmod 755 MicroBrowser/MicroBrowser
chmod 755 MicroBrowser/*.sh

echo "Add shortcut"
envsubst < MicroBrowser/install/MicroBrowser.desktop > ${HOME}/Desktop/MicroBrowser.desktop && 
chmod 755 ${HOME}/Desktop/MicroBrowser.desktop &&
echo "done under:" && ls ${HOME}/Desktop/MicroBrowser.desktop || 
echo "Error: Failed to create desktop file into ${HOME}/Desktop/MicroBrowser.desktop"

# Create autostart dir if not exist

echo -n "> Add Autostart script (y/n)? "
read answer
if [ "$answer" != "${answer#[Yy]}" ] ; then
   echo "Autostart:"
   [ ! -d ${HOME}/.config/autostart ] && mkdir ${HOME}/.config/autostart
   [ -d ${HOME}/.config/autostart ] && 
   envsubst < MicroBrowser/install/microbrowser_autostart.desktop > ${HOME}/.config/autostart/microbrowser_autostart.desktop && 
   chmod 755 ${HOME}/.config/autostart/microbrowser_autostart.desktop &&
   echo "The MicroBrowser will automatically start with Linux, using file:" &&
   ls ${HOME}/.config/autostart/microbrowser_autostart.desktop || 
   echo "Error: Failed to create autostart file into ${HOME}/.config/autostart/microbrowser_autostart.desktop"
else
   echo "No autostart"
   rm -f ${HOME}/.config/autostart/microbrowser_autostart.desktop
fi
sleep 1

# cp MicroBrowser/install/microbrowser_autostart.desktop ${HOME}/.config/autostart/ || echo "Failed to copy autostart file"
# cp MicroBrowser/install/MicroBrowser.desktop ${HOME}/Desktop/ || echo "Failed to copy desktop file"

# Copy xfce config files if any
#[ -d MicroBrowser/install/xfce4 ] && cp -f MicroBrowser/install/xfce4/*.xml ${HOME}/.config/xfce4/xfconf/xfce-perchannel-xml/

# Copy property files
echo "Copy current settings"
FILE=${HOME}/MicroBrowser/mb_config.ini  && [ -e $FILE ] && cp -f $FILE MicroBrowser/ && echo "Copy $FILE"
FILE=${HOME}/MicroBrowser/uBrowser.xml   && [ -e $FILE ] && cp -f $FILE MicroBrowser/ && echo "Copy $FILE"
FILE=${HOME}/MicroBrowser/uBrowser.oem   && [ -e $FILE ] && cp -f $FILE MicroBrowser/ && echo "Copy $FILE"
unset FILE

echo "Kill MicroBrowser"
pkill MicroBrowser
echo "Replace ${HOME}/MicroBrowser directory"
rm -rf ${HOME}/MicroBrowser && mv MicroBrowser ${HOME}/ && cd $HOME && rm -rf $tmp_dir && echo "Done." || echo "Error: Failed to move MicroBrowser directory?"
# Restart MicroBrowser ?
echo "-----"
echo "To start MicroBrowser in Full Screen, set the kiosk mode to 1 in the configuration file: ${HOME}/MicroBrowser/uBrowser.xml"
echo " Or launch the following command line to set kiosk mode: "
echo "  sed -i 's@<kiosk>0@<kiosk>1@g' ${HOME}/MicroBrowser/uBrowser.xml"
echo " Reset to 0 with:"
echo "  sed -i 's@<kiosk>1@<kiosk>0@g' ${HOME}/MicroBrowser/uBrowser.xml"
echo " And check the kiosk setting with:"
echo "  cat ~/MicroBrowser/uBrowser.xml |grep kiosk"
echo "Kill the MicroBrowser with Alt+F4 or with the command line: pkill MicroBrowser"
echo ""